==> content_moderation_edit_notify-8.x-1.1.tar.gz: content_moderation_edit_notify/tests/src/FunctionalJavascript/ContentModerationNotifyJsTest.php <==
<?php

namespace Drupal\Tests\content_moderation_edit_notify\FunctionalJavascript;

use Behat\Mink\Session;

/**
 * Tests Functional Javascript.
 *
 * @group action
 */
class ContentModerationNotifyJsTest extends ContentModerationNotifyTestBase {

  /**
   * Tests a node that is concurrently edited on the full node form.
   */
  public function testConcurrentEdit() {

    // Editor 1 login to create a moderated content.
    $this->drupalLogin($this->editor_1);

    // Create new moderated content in draft
    $this->drupalPostForm('node/add/page', [
      'title[0][value]' => 'Draft page',
      'body[0][value]' => 'First version of the page.',
      'moderation_state[0][state]' => 'draft',
    ], $this->t('Save'));

    $node = $this->drupalGetNodeByTitle('Draft page');
    $nid = $node->id();
    $edit_path = 'node/' . $nid . '/edit';

    // Open version for editing.
    $this->drupalGet($edit_path);

    // Switch to a concurrent session and save an edit change.
    // We need to do some bookkeeping to keep track of the logged in user.
    $logged_in_editor_1 = $this->loggedInUser;
    $this->loggedInUser = FALSE;

    // Register a session to preform concurrent editing.
    $driver = $this->getDefaultDriverInstance();
    $session = new Session($driver);
    $this->mink->registerSession('concurrent', $session);
    $this->mink->setDefaultSessionName('concurrent');
    $this->initFrontPage();
    $logged_in_editor_2 = $this->loggedInUser;

    // As editor 2 we edit the content and save.
    $this->drupalLogin($this->editor_2);
    $this->drupalGet($edit_path);
    $this->drupalPostForm(NULL, [
      'title[0][value]' => 'Draft page EDITED',
      'body[0][value]' => 'Edited version of the page.',
      'moderation_state[0][state]' => 'draft',
    ], $this->t('Save'));

    // Switch back to the default session for editor_1.
    $this->mink->setDefaultSessionName('default');
    $this->loggedInUser = $logged_in_editor_1;

    // Wait for the js message to appear.
    // Method assertWaitOnAjaxRequest is not working probably because of
    // sessions switch.
    sleep($this->interval);

    $this->createScreenshot(\Drupal::root() . '/sites/simpletest/browser_output/edit_page_draft_message.png');

    $this->assertSession()->pageTextContains('unpublished revision');

    // Refresh the edit page.
    $this->drupalGet($edit_path);

    // Switch back to the concurrent session for editor_2 and publish.
    $this->mink->setDefaultSessionName('concurrent');
    $this->loggedInUser = $logged_in_editor_2;
    $this->drupalGet($edit_path);
    $this->drupalPostForm(NULL, [
      'title[0][value]' => 'Published page',
      'body[0][value]' => 'Published version of the page.',
      'moderation_state[0][state]' => 'published',
    ], $this->t('Save'));

    // Check message for editor_1
    $this->mink->setDefaultSessionName('default');
    $this->loggedInUser = $logged_in_editor_1;

    // Wait for the js message to appear.
    sleep($this->interval);

    $this->createScreenshot(\Drupal::root() . '/sites/simpletest/browser_output/edit_page_published_message.png');

    $this->assertSession()->pageTextContains('published revision');
  }

}

==> content_moderation_edit_notify-8.x-1.2.tar.gz: content_moderation_edit_notify/tests/src/FunctionalJavascript/ContentModerationNotifyJsTest.php <==
<?php

namespace Drupal\Tests\content_moderation_edit_notify\FunctionalJavascript;

use Behat\Mink\Session;

/**
 * Tests Functional Javascript.
 *
 * @group action
 */
class ContentModerationNotifyJsTest extends ContentModerationNotifyTestBase {

  /**
   * Tests a node that is concurrently edited on the full node form.
   */
  public function testConcurrentEdit() {

    // Editor 1 login to create a moderated content.
    $this->drupalLogin($this->editor_1);

    // Create new moderated content in draft.
    $this->drupalPostForm('node/add/page', [
      'title[0][value]' => 'Draft page',
      'body[0][value]' => 'First version of the page.',
      'moderation_state[0][state]' => 'draft',
    ], $this->t('Save'));

    $node = $this->drupalGetNodeByTitle('Draft page');
    $nid = $node->id();
    $edit_path = 'node/' . $nid . '/edit';

    // Open version for editing.
    $this->drupalGet($edit_path);

    // Switch to a concurrent session and save an edit change.
    // We need to do some bookkeeping to keep track of the logged in user.
    $logged_in_editor_1 = $this->loggedInUser;
    $this->loggedInUser = FALSE;

    // Register a session to preform concurrent editing.
    $driver = $this->getDefaultDriverInstance();
    $session = new Session($driver);
    $this->mink->registerSession('concurrent', $session);
    $this->mink->setDefaultSessionName('concurrent');
    $this->initFrontPage();
    $logged_in_editor_2 = $this->loggedInUser;

    // As editor 2 we edit the content and save.
    $this->drupalLogin($this->editor_2);
    $this->drupalGet($edit_path);
    $this->drupalPostForm(NULL, [
      'title[0][value]' => 'Draft page EDITED',
      'body[0][value]' => 'Edited version of the page.',
      'moderation_state[0][state]' => 'draft',
    ], $this->t('Save'));

    // Switch back to the default session for editor 1.
    $this->mink->setDefaultSessionName('default');
    $this->loggedInUser = $logged_in_editor_1;

    // Wait for the js message to appear.
    // Method assertWaitOnAjaxRequest is not working probably because of
    // sessions switch.
    sleep($this->interval);

    $this->createScreenshot(\Drupal::root() . '/sites/simpletest/browser_output/edit_page_draft_message.png');

    $this->assertSession()->pageTextContains('unpublished revision');

    // Refresh the edit page.
    $this->drupalGet($edit_path);

    // Switch back to the concurrent session for editor 2 and publish.
    $this->mink->setDefaultSessionName('concurrent');
    $this->loggedInUser = $logged_in_editor_2;
    $this->drupalGet($edit_path);
    $this->drupalPostForm(NULL, [
      'title[0][value]' => 'Published page',
      'body[0][value]' => 'Published version of the page.',
      'moderation_state[0][state]' => 'published',
    ], $this->t('Save'));

    // Check message for editor 1.
    $this->mink->setDefaultSessionName('default');
    $this->loggedInUser = $logged_in_editor_1;

    // Wait for the js message to appear.
    sleep($this->interval);

    $this->createScreenshot(\Drupal::root() . '/sites/simpletest/browser_output/edit_page_published_message.png');

    $this->assertSession()->pageTextContains('published revision');
  }

}
